==> nextcloud-app-mail-0.7.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/nl.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "E-mail",
    "Loading accounts …" : "Laden van accounts …",
    "Error while loading the accounts." : "Fout tijdens het laden van de accounts.",
    "Error while loading the selected account." : "Fout tijdens het laden van het gekozen account.",
    "Can not load this folder." : "Kan deze map niet laden.",
    "Loading {folder}" : "Laden {folder}",
    "Searching for {query}" : "Zoeken naar {query}",
    "Error while deleting message." : "Fout bij verwijderen bericht.",
    "Forwarded message" : "Doorgestuurd bericht",
    "Choose a folder to store the attachment in" : "Kies een map op de bijlage in op te slaan",
    "Attachments saved to Files." : "Bjilagen opgeslagen in Bestanden.",
    "Attachment saved to Files." : "Bijlage opgeslagen in Bestanden.",
    "Error while saving attachments to Files." : "Fout bij opslaan bijlagen in Bestanden.",
    "Error while saving attachment to Files." : "Fout bij opslaan bijlage in Bestanden.",
    "Message flag could not be set." : "Bericht kon niet als gemarkeerd worden.",
    "Could not move message." : "Kon bericht niet verplaatsen",
    "Invalid account" : "Ongeldig account",
    "Invalid folder" : "Ongeldige map",
    "Error while creating the account: " : "Fout bij het creëren van een account:",
    "Unknown error" : "Onbekende fout",
    "All inboxes" : "Alle postvakken",
    "you" : "jou",
    "Send message to {email}" : "Verstuur email aan {email}",
    "Could not load {tag}{name}{endtag}" : "Kon niet laden {tag}{name}{endtag}",
    "We couldn’t load {tag}{name}{endtag}" : "{tag}{name}{endtag} kon niet worden geladen",
    "There was a problem loading {tag}{name}{endtag}" : "Er is een probleem bij het laden {tag}{name}{endtag}",
    "We couldn’t load your message" : "Bericht kon niet worden geladen",
    "Unable to load the desired message" : "Gewenste bericht kon niet worden geladen",
    "There was a problem loading the message" : "Het laden van het bericht was problematisch",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nieuw bericht \nvan {from}","%n niewe berichten \nvan {from}"],
    "Nextcloud Mail" : "Nextcloud E-mail",
    "Show all folders" : "Laat alle mappen zien",
    "Collapse folders" : "Mappen inklappen",
    "Error while deleting account." : "Fout bij verwijderen account.",
    "Choose a file to add as attachment" : "Kies een bestand om als bijlage toe te voegen",
    "An error occurred while uploading {fname}" : "Er trad een fout op bij het uploaden van {fname}",
    "Reply" : "Antwoord",
    "Send" : "Versturen",
    "Sending …" : "Versturen ...",
    "Message sent!" : "Bericht verzonden!",
    "Server error" : "Serverfout",
    "An unknown error occurred" : "Een onbekend probleem vond plaats",
    "Opening HTML drafts is not supported yet." : "Openen concept HTML wordt nog niet ondersteund.",
    "Draft saved!" : "Concept opgeslagen!",
    "No writable calendars found" : "Geen beschijfbare agenda's gevonden",
    "Error while importing the calendar event" : "Fout bij importeren agenda-afspraak",
    "Error while downloading calendar event" : "Fout bij downloaden agenda-afspraak",
    "Error while loading messages." : "Fout bij laden berichten.",
    "Error while refreshing messages." : "Foutmelding tijdens verversen van berichten.",
    "Setting up your account" : "Je account opzetten",
    "Inbox" : "Postvak in",
    "Sent" : "Verzonden",
    "Drafts" : "Concepten",
    "Archive" : "Archief",
    "Trash" : "Verwijderen",
    "Junk" : "Afval",
    "All" : "Alle",
    "Favorites" : "Favorieten",
    "Creating account failed: " : "Aanmaken account mislukt:",
    "Auto detect failed. Please use manual mode." : "Automatisch vaststellen mislukt. Gebruik handmatige modus.",
    "Delete permanently" : "Definitief verwijderen",
    "& others" : "& anderen",
    "Error loading message" : "Fout bij laden bericht",
    "Settings" : "Instellingen",
    "Forwarding to %s" : "Doorsturen aan %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klik hier als je binnen enkele seconden niet automatisch wordt doorgestuurd.",
    "Redirect" : "Omleiden",
    "The link leads to %s" : "De link verwijst naar %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Als u die pagina niet wilt bezoeken, kunt u teruggaan naar <a href=\"%s\">E-mail</a>.",
    "Continue to %s" : "Verder naar %s",
    "Delete account" : "Verwijder account",
    "Try again" : "Probeer opnieuw",
    "New message" : "Nieuw bericht",
    "Account Settings" : "Account instellingen",
    "Aliases" : "Aliassen",
    "Mail address" : "E-mailadres",
    "Display Name" : "Weergavenaam",
    "Save" : "Opslaan",
    "Keyboard shortcuts" : "Sneltoetsen",
    "Speed up your Mail experience with these quick shortcuts." : "Versnel je e-mail-ervaring met deze handige snelkoppelingen.",
    "Compose new message" : "Opstellen nieuw bericht",
    "Newer message" : "Recenter bericht",
    "Older message" : "Ouder bericht",
    "Toggle star" : "Omschakelen ster",
    "Toggle unread" : "Omschakelen ongelezen",
    "Delete" : "Verwijderen",
    "Search" : "Zoeken",
    "Refresh" : "Verversen",
    "Connect your mail account" : "verbind je e-mailaccount",
    "Name" : "Naam",
    "Mail Address" : "E-mailadres",
    "Password" : "Wachtwoord",
    "Manual configuration" : "Handmatig configureren",
    "IMAP Host" : "IMAP host",
    "IMAP security" : "IMAP security",
    "None" : "Geen",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP poort",
    "IMAP User" : "IMAP gebruikersnaam",
    "IMAP Password" : "IMAP wachtwoord",
    "SMTP Host" : "SMTP host",
    "SMTP security" : "SMTP security",
    "SMTP Port" : "SMTP poort",
    "SMTP User" : "SMTP gebruikersnaam",
    "SMTP Password" : "SMTP wachtwoord",
    "Connect" : "Verbinden",
    "from" : "van",
    "to" : "aan",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "Onderwerp",
    "Save all to Files" : "Sla alles op in Bestanden",
    "Add mail account" : "Voeg e-mail account toe",
    "No search results for" : "Geen resultaten gevonden voor",
    "The images have been blocked to protect your privacy." : "De afbeeldingen zijn geblokkeerd om jouw privacy te beschermen",
    "Show images from this sender" : "Laat afbeeldingen zien van deze afzender",
    "Forward" : "Doorsturen",
    "Add attachment" : "Toevoegen bijlage",
    "Add from Files" : "Toevoegen uit bestanden",
    "Import into calendar" : "Toevoegen aan agenda",
    "Download attachment" : "Download bijlage",
    "Save to Files" : "Opslaan in Bestanden"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-0.7.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/nl.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "E-mail",
    "Loading accounts" : "Accounts laden",
    "Error while loading the accounts." : "Fout tijdens het laden van de accounts.",
    "Error while loading the selected account." : "Fout tijdens het laden van het gekozen account.",
    "Can not load this folder." : "Kan deze map niet laden.",
    "Searching for {query}" : "Zoeken naar {query}",
    "Error while deleting message." : "Fout bij verwijderen bericht.",
    "Forwarded message" : "Doorgestuurd bericht",
    "Choose a folder to store the attachment in" : "Kies een map op de bijlage in op te slaan",
    "Attachments saved to Files." : "Bjilagen opgeslagen in Bestanden.",
    "Attachment saved to Files." : "Bijlage opgeslagen in Bestanden.",
    "Error while saving attachments to Files." : "Fout bij opslaan bijlagen in Bestanden.",
    "Error while saving attachment to Files." : "Fout bij opslaan bijlage in Bestanden.",
    "Message flag could not be set." : "Bericht kon niet als gemarkeerd worden.",
    "Could not move message." : "Kon bericht niet verplaatsen",
    "Invalid account" : "Ongeldig account",
    "Invalid folder" : "Ongeldige map",
    "Error while creating the account: " : "Fout bij het creëren van een account:",
    "Unknown error" : "Onbekende fout",
    "All inboxes" : "Alle postvakken",
    "you" : "jou",
    "Send message to {email}" : "Verstuur email aan {email}",
    "Could not load {tag}{name}{endtag}" : "Kon niet laden {tag}{name}{endtag}",
    "We couldn’t load {tag}{name}{endtag}" : "{tag}{name}{endtag} kon niet worden geladen",
    "There was a problem loading {tag}{name}{endtag}" : "Er is een probleem bij het laden {tag}{name}{endtag}",
    "We couldn’t load your message" : "Bericht kon niet worden geladen",
    "Unable to load the desired message" : "Gewenste bericht kon niet worden geladen",
    "There was a problem loading the message" : "Het laden van het bericht was problematisch",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nieuw bericht \nvan {from}","%n niewe berichten \nvan {from}"],
    "Nextcloud Mail" : "Nextcloud E-mail",
    "Show all folders" : "Laat alle mappen zien",
    "Collapse folders" : "Mappen inklappen",
    "Error while deleting account." : "Fout bij verwijderen account.",
    "Choose a file to add as attachment" : "Kies een bestand om als bijlage toe te voegen",
    "An error occurred while uploading {fname}" : "Er trad een fout op bij het uploaden van {fname}",
    "Reply" : "Antwoord",
    "Send" : "Versturen",
    "Sending …" : "Versturen ...",
    "Message sent!" : "Bericht verzonden!",
    "Server error" : "Serverfout",
    "An unknown error occurred" : "Een onbekend probleem vond plaats",
    "Opening HTML drafts is not supported yet." : "Openen concept HTML wordt nog niet ondersteund.",
    "Draft saved!" : "Concept opgeslagen!",
    "No writable calendars found" : "Geen beschijfbare agenda's gevonden",
    "Error while importing the calendar event" : "Fout bij importeren agenda-afspraak",
    "Error while downloading calendar event" : "Fout bij downloaden agenda-afspraak",
    "Error while loading messages." : "Fout bij laden berichten.",
    "Error while refreshing messages." : "Foutmelding tijdens verversen van berichten.",
    "Setting up your account" : "Je account opzetten",
    "Inbox" : "Postvak in",
    "Sent" : "Verzonden",
    "Drafts" : "Concepten",
    "Archive" : "Archief",
    "Trash" : "Verwijderen",
    "Junk" : "Afval",
    "All" : "Alle",
    "Favorites" : "Favorieten",
    "Auto detect failed. Please use manual mode." : "Automatisch vaststellen mislukt. Gebruik handmatige modus.",
    "Creating account failed: " : "Aanmaken account mislukt:",
    "Delete permanently" : "Definitief verwijderen",
    "& others" : "& anderen",
    "Error loading message" : "Fout bij laden bericht",
    "Settings" : "Instellingen",
    "Forwarding to %s" : "Doorsturen aan %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klik hier als je binnen enkele seconden niet automatisch wordt doorgestuurd.",
    "Redirect" : "Omleiden",
    "The link leads to %s" : "De link verwijst naar %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Als u die pagina niet wilt bezoeken, kunt u teruggaan naar <a href=\"%s\">E-mail</a>.",
    "Continue to %s" : "Verder naar %s",
    "Delete account" : "Verwijder account",
    "Try again" : "Probeer opnieuw",
    "New message" : "Nieuw bericht",
    "Account Settings" : "Account instellingen",
    "Aliases" : "Aliassen",
    "Mail address" : "E-mailadres",
    "Display Name" : "Weergavenaam",
    "Save" : "Opslaan",
    "Keyboard shortcuts" : "Sneltoetsen",
    "Speed up your Mail experience with these quick shortcuts." : "Versnel je e-mail-ervaring met deze handige snelkoppelingen.",
    "Compose new message" : "Opstellen nieuw bericht",
    "Newer message" : "Recenter bericht",
    "Older message" : "Ouder bericht",
    "Toggle star" : "Omschakelen ster",
    "Toggle unread" : "Omschakelen ongelezen",
    "Delete" : "Verwijderen",
    "Search" : "Zoeken",
    "Refresh" : "Verversen",
    "Connect your mail account" : "verbind je e-mailaccount",
    "Name" : "Naam",
    "Mail Address" : "E-mailadres",
    "Password" : "Wachtwoord",
    "Manual configuration" : "Handmatig configureren",
    "IMAP Host" : "IMAP host",
    "IMAP security" : "IMAP security",
    "None" : "Geen",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP poort",
    "IMAP User" : "IMAP gebruikersnaam",
    "IMAP Password" : "IMAP wachtwoord",
    "SMTP Host" : "SMTP host",
    "SMTP security" : "SMTP security",
    "SMTP Port" : "SMTP poort",
    "SMTP User" : "SMTP gebruikersnaam",
    "SMTP Password" : "SMTP wachtwoord",
    "Connect" : "Verbinden",
    "from" : "van",
    "to" : "aan",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "Onderwerp",
    "Save all to Files" : "Sla alles op in Bestanden",
    "Add mail account" : "Voeg e-mail account toe",
    "No search results for" : "Geen resultaten gevonden voor",
    "The images have been blocked to protect your privacy." : "De afbeeldingen zijn geblokkeerd om jouw privacy te beschermen",
    "Show images from this sender" : "Laat afbeeldingen zien van deze afzender",
    "Forward" : "Doorsturen",
    "No messages in this folder!" : "Geen berichten in deze map!",
    "Upload attachment" : "Bijlage uploaden",
    "Add attachment from Files" : "Bijlage toevoegen vanuit Bestanden",
    "Import into calendar" : "Toevoegen aan agenda",
    "Download attachment" : "Download bijlage",
    "Save to Files" : "Opslaan in Bestanden"
},
"nplurals=2; plural=(n != 1);");
